<?php
/**
 * @file clase_zen_plantilla.php
 * @author Juan Belon
 * @access public
 * @copyright LGPL, GPL
 * @package zenphp
 * @version 1.0
 * @uses zenphp FrameWork
 * 
 * @brief La clase más simple que se me ha ocurrido para operar con plantillas
//TODO: recordar recortar los ficheros de plantillas en varios para no tener cadenas de longitud muy grande que es altamente ineficiente!
 */
// +----------------------------------------------------------------------
// | zenphp.es
// +----------------------------------------------------------------------
if (!defined('ZF_SEGURO_ZEN')) exit('Acceso directo no permitido');
class zen_plantilla {
	/**
 	 * Contenido de la pagina actual
 	 *
 	 * @var str
 	 */
	var $contenido;
	/**
 	 * Constructor: si se le pasa un fichero lo carga directamente
 	 *
 	 * @param str $fichero
 	 * @return plantilla
 	 */
	function zen_plantilla($fichero=""){
		if (!empty($fichero) && !is_a($fichero,'zen')){ //No queremos asociarla a ninguna aplicacion
			if (!$this->cargar($fichero)){
				zen__manejador_de_errores(E_WARNING,"<img src='".ZF_CARPETA_ZEN."/contenido/img/e_plantilla.png'> &nbsp; No se pudo cargar el fichero de plantilla ".$fichero." de los directorios de plantillas<br> &middot; ".
				ZF_DIR_IDIOMA." <br> &middot; ".ZF_DIR_PLANTILLAS,'zen_php/clases/zen_clase_plantilla.php','<b>19</b>');
			}
		}
	}

	/**
 	 * Carga un fichero de plantilla y lo almacena en $this->contenido y devuelve el resultado de la operacion
 	 * Si la ruta esta vacia lo buscara en los directorios de plantillas,en otro caso intenta abrirlo desde
 	 * la ruta pasada y devuelve el resultado como un booleano
 	 *
 	 * @param str $fichero
 	 * @param str $ruta
 	 * @return bool 
 	 */
	function cargar($fichero,$ruta=""){
		$this->contenido = "";
		if (empty($ruta)){
			//Directorio principal de plantillas
			if (!file_exists(ZF_DIR_PLANTILLAS.$fichero)) {
				if (file_exists(ZF_DIR_IDIOMA.$fichero)){
				  @$this->contenido = file_get_contents(ZF_DIR_IDIOMA.$fichero);
				} elseif(!file_exists(ZF_DIR_CONTENIDO_ZEN.$fichero)){
					//Directorio de plantillas de zenphp, lo más interior:
					return false;
				} else{
					//Devolver
					@$this->contenido = file_get_contents(ZF_DIR_CONTENIDO_ZEN.$fichero);
				}
			} else {
				//Devolver
				@$this->contenido = file_get_contents(ZF_DIR_PLANTILLAS.$fichero);
			}
		} else {
			//Ruta proporcionada:
			if (substr($ruta,-1,1)!=DIRECTORY_SEPARATOR) $ruta .= DIRECTORY_SEPARATOR;
			if (!file_exists($ruta.$fichero)) {
				//Error
				return false;
			}
			else { //Devolver
				@$this->contenido = file_get_contents($ruta.$fichero);
			}
		}
		//Fin->resultado:
		return (!empty($this->contenido));
	}

	/**
 	 * Reemplaza las etiquetas de la plantilla dadas por $var con $contenido en $this->contenido: la plantilla HTML
 	 *
 	 * @param str $var
 	 * @param str $contenido
 	 */
	function reemplazar($var, $contenido) {
		$this->contenido = str_replace("#$var#", $contenido, $this->contenido);
	}

	/**
   	 * Reemplaza el contenido por texto y lo muestra, borra de memoria la plantilla HTML de la clase $this->contenido
   	 *
   	 */
	function mostrar() {
		eval("?>".$this->contenido."<?");
		unset($this->contenido);
	}

	/**
	 * Reemplaza las constantes de la plantilla por los contenidos y devuelve el resultado en HTML
	 *
	 * @param str $fichero
	 * @param array $reemplazos
	 * @return str : html
	 */
	function rellena_HTML($fichero,$reemplazos=array()){
		$this->cargar($fichero);
		$this->pasarAplantilla($reemplazos);
		return $this->contenido;
	}

	/**
	 * Usando la clase plantilla pasada reemplaza los valores de la matriz del argumento
	 *
	 * @param array $array
	 * @return bool
	 */
	function pasarAplantilla($array) {
		if (!is_array($array)) return false;
		foreach ($array as $llave => $valor) {
			$this->reemplazar($llave,$valor);
		}
		return true;
	}
	/**
  * Devuelve el contenido, si se pasa un fichero se carga previamente
  *
  * @param str $f
  * @return str
  */
	function devolver_contenido($f=''){
		if (!empty($f)) $this->cargar($f);
		return $this->contenido;
	}
	/**
  * Devuelve el contenido del fichero si se pasa (sino se usa el que tenga),previamente se reemplaza $reemplazos
  *
  * @param str $f
  * @param array $reemplazos
  * @return str
  */
	function contenido_reemplaza($f='',$reemplazos){
		if (!empty($f)) $this->cargar($f);
		$this->pasarAplantilla($reemplazos);
		return $this->contenido;
	}
}

?>